.. image:: https://travis-ci.org/ambitioninc/pagerduty-api.png
   :target: https://travis-ci.org/ambitioninc/pagerduty-api


pagerduty-api
===============
pagerduty-api is a package for easily interacting with PagerDuty's API.

Why?
----

There are several other libraries interacting with the PagerDuty API, however none of them include
tests and documentation.

Installation
------------

To install the latest release, type::

    pip install pagerduty-api

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/pagerduty-api.git


Requirements
------------

* Python 2.7, 3.3, 3,4
* requests >= 2.0.0

Documentation
-------------

Full documentation is available at http://pagerduty-api.readthedocs.org

License
-------
MIT License (see LICENSE)